==> plasma-widget-yawp_0.3.2.orig.tar.bz2: yawp-0.3.2/unittest/iontest.h <==
/*************************************************************************\
*   Copyright (C) 2009 by                                     *
*                                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
\*************************************************************************/

#ifndef IONTEST_H
#define IONTEST_H

//--- LOCAL ---
#include "ions/ion_accuweather.h"
//#include "ions/ion_google.h"

//--- QT4 ---
#include <QObject>

//--- KDE4 ---
#include <plasma/dataengine.h>
#include <plasma/weather/ion.h>

class IonTester	: public QObject
{
	Q_OBJECT
public:
	IonTester( QObject * parent = NULL );
	~IonTester();

	void connectSource( const QString & source );
	void reset();

public slots:
	void dataUpdated(const QString & sourceName, const Plasma::DataEngine::Data & data);

	void quit();

private:
	AccuWeatherIon  m_ion;
//	GoogleIon	m_ion;
};

#endif // IONTEST_H

==> plasma-widget-yawp_0.4.1.orig.tar.bz2: yawp-0.4.1/unittest/iontest.h <==
/*************************************************************************\
*   Copyright (C) 2009 by                                     *
*                                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
\*************************************************************************/

#ifndef IONTEST_H
#define IONTEST_H

//--- LOCAL ---
#include "ions/ion_accuweather.h"
//#include "ions/ion_google.h"

//--- QT4 ---
#include <QObject>

//--- KDE4 ---
#include <Plasma/DataEngine>
#include <Plasma/Weather/Ion>

class IonTester	: public QObject
{
	Q_OBJECT
public:
	IonTester( QObject * parent = NULL );
	~IonTester();

	void connectSource( const QString & source );
	void reset();

public slots:
	void dataUpdated(const QString & sourceName, const Plasma::DataEngine::Data & data);

	void quit();

private:
	AccuWeatherIon  m_ion;
//	GoogleIon	m_ion;
};

#endif // IONTEST_H
